@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2011 by Pablo Martín <goinnn@gmail.com>
+# Copyright (c) 2013 by Pablo Martín <goinnn@gmail.com>
 #
 # This software is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -34,7 +34,7 @@ def togglePrettyJsonFormat():
     try:
         target = simplejson.dumps(simplejson.loads(source), indent=2)
         view.removeSelectionText()
-        insertText(target.replace("u'", '"'))
+        insertText(target)
     except simplejson.JSONDecodeError:
         kate.gui.popup('This text is not a valid json text', 2,
                        icon='dialog-warning',
